==> quantlib_1.15.orig.tar.gz: QuantLib-1.15/test-suite/nthorderderivativeop.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2018 Klaus Spanderen

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#ifndef quantlib_test_nth_order_derivative_op_hpp
#define quantlib_test_nth_order_derivative_op_hpp

#include <boost/test/unit_test.hpp>

class NthOrderDerivativeOpTest {
   public:
    static void testSparseMatrixApply();
    static void testFirstOrder2PointsApply();
    static void testFirstOrder3PointsOnUniformGrid();
    static void testFirstOrder5PointsOnUniformGrid();
    static void testFirstOrder2PointsOnUniformGrid();
    static void testFirstOrder4PointsOnUniformGrid();
    static void testFirstOrder2PointsOn2DimUniformGrid();
    static void testSecondOrder3PointsNonUniformGrid();
    static void testSecondOrder4PointsNonUniformGrid();
    static void testThirdOrder4PointsUniformGrid();
    static void testHigerOrderBSOptionPricing();
    static void testHigerOrderAndRichardsonExtrapolationg();

    static boost::unit_test_framework::test_suite* suite();
};

#endif

==> quantlib_1.29.orig.tar.gz: QuantLib-1.29/test-suite/nthorderderivativeop.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2018 Klaus Spanderen

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#ifndef quantlib_test_nth_order_derivative_op_hpp
#define quantlib_test_nth_order_derivative_op_hpp

#include <boost/test/unit_test.hpp>
#include "speedlevel.hpp"

class NthOrderDerivativeOpTest {
   public:
    static void testSparseMatrixApply();
    static void testFirstOrder2PointsApply();
    static void testFirstOrder3PointsOnUniformGrid();
    static void testFirstOrder5PointsOnUniformGrid();
    static void testFirstOrder2PointsOnUniformGrid();
    static void testFirstOrder4PointsOnUniformGrid();
    static void testFirstOrder2PointsOn2DimUniformGrid();
    static void testSecondOrder3PointsNonUniformGrid();
    static void testSecondOrder4PointsNonUniformGrid();
    static void testThirdOrder4PointsUniformGrid();
    static void testHigherOrderHestonOptionPricing();
    static void testHigherOrderAndRichardsonExtrapolation();
    static void testCompareFirstDerivativeOpNonUniformGrid();
    static void testCompareFirstDerivativeOp2dUniformGrid();
    static void testMixedSecondOrder9PointsOnUniformGrid();

    static boost::unit_test_framework::test_suite* suite(SpeedLevel);
};

#endif
